/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.element.impl;

import java.util.Map;

import org.ow2.bonita.facade.def.element.HookDefinition;
import org.ow2.bonita.util.CopyTool;
import org.ow2.bonita.util.Misc;


public class HookDefinitionImpl implements HookDefinition {

  /**
   * 
   */
  private static final long serialVersionUID = 6559827592184640374L;
  protected String className;
  protected Event event;
  protected Map<String, String> parameters;
  protected boolean throwingException;

  protected HookDefinitionImpl() { }

  public HookDefinitionImpl(final String className, final Event event,
      final Map<String, String> parameters, final boolean throwingException) {
    super();
    Misc.checkArgsNotNull(className, event, throwingException);
    this.className = className;
    this.event = event;
    this.parameters = parameters;
    this.throwingException = throwingException;
  }

  public HookDefinitionImpl(final HookDefinition src) {
    Misc.badStateIfNull(src, "Ouch! Impossible to build a new Definition object from null");
    this.className = src.getClassName();
    this.event = src.getEvent();
    this.parameters = CopyTool.copy(src.getParameters());
    this.throwingException = src.isThrowingException();
  }

  public String getClassName() {
    return this.className;
  }

  public Event getEvent() {
    return this.event;
  }

  public Map<String, String> getParameters() {
    return this.parameters;
  }

  public boolean isThrowingException() {
    return this.throwingException;
  }

}


