/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import java.util.HashSet;
import java.util.Set;

import org.ow2.bonita.facade.def.majorElement.ActivityDefinition;
import org.ow2.bonita.facade.def.majorElement.ActivitySetDefinition;
import org.ow2.bonita.facade.def.majorElement.TransitionDefinition;
import org.ow2.bonita.facade.uuid.ActivitySetDefinitionUUID;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;

public class ActivitySetDefinitionImpl extends ProcessDefinitionRecordImpl implements ActivitySetDefinition {

  /**
   * 
   */
  private static final long serialVersionUID = 8832032092720710424L;
  protected ActivitySetDefinitionUUID uuid;
  protected String activitySetId;
  protected Set<ActivityDefinition> activities;
  protected Set<TransitionDefinition> transitions;

  protected ActivitySetDefinitionImpl() { }

  public ActivitySetDefinitionImpl(ActivitySetDefinitionUUID uuid, String activitySetId,
      PackageDefinitionUUID packageUUID,
      ProcessDefinitionUUID processUUID, String name, Set<ActivityDefinition> activities,
      Set<TransitionDefinition> transitions) {
    super(packageUUID, name, processUUID);
    this.uuid = uuid;
    this.activitySetId = activitySetId;
    this.activities = activities;
    this.transitions = transitions;
  }

  public ActivitySetDefinitionImpl(ActivitySetDefinition src) {
    super(src);
    this.uuid = new ActivitySetDefinitionUUID(src.getUUID());
    this.activitySetId = src.getActivitySetId();
    Set<ActivityDefinition> activities = src.getActivities();
    if (activities != null) {
      this.activities = new HashSet<ActivityDefinition>();
      for (ActivityDefinition d : activities) {
        this.activities.add(new ActivityDefinitionImpl(d));
      }
    }

    Set<TransitionDefinition> transitions = src.getTransitions();
    if (transitions != null) {
      this.transitions = new HashSet<TransitionDefinition>();
      for (TransitionDefinition d : transitions) {
        this.transitions.add(new TransitionDefinitionImpl(d));
      }
    }
  }

  public Set<ActivityDefinition> getActivities() {
    return activities;
  }


  public Set<TransitionDefinition> getTransitions() {
    return transitions;
  }

  public String getActivitySetId() {
    return activitySetId;
  }

  public ActivitySetDefinitionUUID getUUID() {
    return uuid;
  }

}


