/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import org.ow2.bonita.facade.def.element.BusinessArchive;
import org.ow2.bonita.facade.def.element.ExternalPackageDefinition;
import org.ow2.bonita.facade.def.element.TypeDeclarationDefinition;
import org.ow2.bonita.facade.def.element.impl.BusinessArchiveImpl;
import org.ow2.bonita.facade.def.element.impl.ExternalPackageDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.TypeDeclarationDefinitionImpl;
import org.ow2.bonita.facade.def.majorElement.PackageDefinition;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.util.CopyTool;


public class PackageDefinitionImpl extends DefinitionRecordImpl implements PackageDefinition {

  /**
   * 
   */
  private static final long serialVersionUID = 4853206072443830681L;
  protected PackageDefinitionUUID uuid;
  protected String packageId;
  protected Date deployedDate;
  protected Date undeployedDate;
  protected String deployedBy;
  protected String undeployedBy;

  protected String author;
  protected Set<String> classDependencies;
  protected String codepage;
  protected GraphConformance conformanceClass;
  protected String costUnit;
  protected String countrykey;
  protected String created;
  protected String description;
  protected String documentation;
  protected Set<ExternalPackageDefinition> externalPackages;
  protected Set<String> packageDependencies;
  protected String priorityUnit;
  protected PublicationStatus publicationStatus;
  protected Set<String> responsibles;
  protected String scriptType;
  protected String scriptVersion;
  protected String scriptGrammar;
  protected Set<TypeDeclarationDefinition> typeDeclarations;
  protected String vendor;
  protected String version;
  protected String xpdlVersion;
  protected BusinessArchive businessArchive;
  protected PackageState state;
  
  protected PackageDefinitionImpl() { }

  PackageDefinitionImpl(final PackageDefinitionUUID uuid) {
    super(uuid, null);
  }

  protected PackageDefinitionImpl(final PackageDefinitionUUID uuid, final Date deployedDate, final String deployedBy,
      final Date undeployedDate, final String undeployedBy,
      final String packageId, final String name, final String author, final Set<String> classDependencies,
      final String codepage, final GraphConformance conformanceClass, final String costUnit,
      final String countrykey, final String created, final String description, final String documentation,
      final Set<ExternalPackageDefinition> externalPackages, final Set<String> packageDependencies,
      final String priorityUnit, final PublicationStatus publicationStatus,
      final Set<String> responsibles, final String scriptType, final String scriptVersion, final String scriptGrammar,
      final Set<TypeDeclarationDefinition> typeDeclarations, final String vendor, final String version,
      final String xpdlVersion, final BusinessArchive businessArchive, final PackageState state) {
    super(uuid, name);
    this.uuid = uuid;
    this.packageId = packageId;
    this.deployedDate = deployedDate;
    this.deployedBy = deployedBy;
    this.undeployedDate = undeployedDate;
    this.undeployedBy = undeployedBy;

    this.author = author;
    this.classDependencies = classDependencies;
    this.codepage = codepage;
    this.conformanceClass = conformanceClass;
    this.costUnit = costUnit;
    this.countrykey = countrykey;
    this.created = created;
    this.description = description;
    this.documentation = documentation;
    this.externalPackages = externalPackages;
    this.packageDependencies = packageDependencies;
    this.priorityUnit = priorityUnit;
    this.publicationStatus = publicationStatus;
    this.responsibles = responsibles;
    this.scriptType = scriptType;
    this.scriptVersion = scriptVersion;
    this.scriptGrammar = scriptGrammar;
    this.typeDeclarations = typeDeclarations;
    this.vendor = vendor;
    this.version = version;
    this.xpdlVersion = xpdlVersion;
    this.businessArchive = businessArchive;
    this.state = state;
  }

  public PackageDefinitionImpl(final PackageDefinition src) {
    super(src);
    this.uuid = new PackageDefinitionUUID(src.getUUID());
    this.packageId = src.getPackageId();
    this.deployedDate = CopyTool.copy(src.getDeployedDate());
    this.undeployedDate = CopyTool.copy(src.getUndeployedDate());
    this.deployedBy = src.getDeployedBy();
    this.undeployedBy = src.getUndeployedBy();
    this.author = src.getAuthor();
    this.classDependencies = CopyTool.copy(src.getClassDependencies());
    this.codepage = src.getCodepage();
    this.conformanceClass = src.getConformanceClass();
    this.costUnit = src.getCostUnit();
    this.countrykey = src.getCountrykey();
    this.created = src.getCreated();
    this.description = src.getDescription();
    this.documentation = src.getDocumentation();
    final Set<ExternalPackageDefinition> externalPackages = src.getExternalPackages();
    if (externalPackages != null) {
      this.externalPackages = new HashSet<ExternalPackageDefinition>();
      for (final ExternalPackageDefinition d : externalPackages) {
        this.externalPackages.add(new ExternalPackageDefinitionImpl(d));
      }
    }
    this.packageDependencies = CopyTool.copy(src.getPackageDependencies());
    this.priorityUnit = src.getPriorityUnit();
    this.publicationStatus = src.getPublicationStatus();
    this.responsibles = CopyTool.copy(src.getResponsibles());
    this.scriptType = src.getScriptType();
    this.scriptVersion = src.getScriptVersion();
    this.scriptGrammar = src.getScriptGrammar();
    final Set<TypeDeclarationDefinition> typeDeclarations = src.getTypeDeclarations();
    if (typeDeclarations != null) {
      this.typeDeclarations = new HashSet<TypeDeclarationDefinition>();
      for (final TypeDeclarationDefinition d : typeDeclarations) {
        this.typeDeclarations.add(new TypeDeclarationDefinitionImpl(d));
      }
    }
    this.vendor = src.getVendor();
    this.version = src.getVersion();
    this.xpdlVersion = src.getXPDLVersion();
    this.businessArchive = new BusinessArchiveImpl(src.getBusinessArchive());
    this.state = src.getState();
  }

  @Override
  public String toString() {
    return this.getClass().getName()
      + "[uuid: " + getUUID()
      + ", packageDefinitionUUID: " + getPackageDefinitionUUID()
      + ", packageId: " + getPackageId() + "]";
  }

  public String getAuthor() {
    return this.author;
  }

  public String getCodepage() {
    return this.codepage;
  }

  public GraphConformance getConformanceClass() {
    return this.conformanceClass;
  }

  public String getCostUnit() {
    return this.costUnit;
  }

  public String getCountrykey() {
    return this.countrykey;
  }

  public String getCreated() {
    return this.created;
  }

  public String getDescription() {
    return this.description;
  }

  public String getDocumentation() {
    return this.documentation;
  }

  public Set<ExternalPackageDefinition> getExternalPackages() {
    return this.externalPackages;
  }

  public String getPriorityUnit() {
    return this.priorityUnit;
  }

  public PublicationStatus getPublicationStatus() {
    return this.publicationStatus;
  }

  public Set<String> getResponsibles() {
    return this.responsibles;
  }

  public String getScriptType() {
    return this.scriptType;
  }

  public String getScriptVersion() {
    return this.scriptVersion;
  }

  public String getScriptGrammar() {
    return this.scriptGrammar;
  }

  public Set<TypeDeclarationDefinition> getTypeDeclarations() {
    return this.typeDeclarations;
  }

  public String getVendor() {
    return this.vendor;
  }

  public String getVersion() {
    return this.version;
  }

  public String getXPDLVersion() {
    return this.xpdlVersion;
  }


  public Set<String> getClassDependencies() {
    return this.classDependencies;
  }

  public Set<String> getPackageDependencies() {
    return this.packageDependencies;
  }

  public String getXpdlVersion() {
    return this.xpdlVersion;
  }

  public Date getDeployedDate() {
    return this.deployedDate;
  }

  public String getDeployedBy() {
    return this.deployedBy;
  }

  public Date getUndeployedDate() {
    return this.undeployedDate;
  }


  public String getUndeployedBy() {
    return this.undeployedBy;
  }

  public String getPackageId() {
    return this.packageId;
  }

  public PackageDefinitionUUID getUUID() {
    return this.uuid;
  }
  
  public BusinessArchive getBusinessArchive() {
    return this.businessArchive;
  }
  
  public PackageState getState() {
    return this.state;
  }
}


